@@ -8,8 +8,7 @@ from fastnumbers import isint, isfloat, fast_int, fast_float
 from itertools import chain
 from joblib import Parallel, delayed
 from math import ceil, log
-#TODO: Remove mmap.ACCESS_READ?
-from mmap import mmap, PROT_READ, ACCESS_READ
+from mmap import mmap, PROT_READ
 from msgspec import msgpack
 from operator import eq, ge, gt, le, lt, ne, itemgetter
 from os import makedirs, path, remove
@@ -26,8 +25,7 @@ FILE_KEY_ABBREVIATIONS_NOCACHE = {"data": 1, "cc": 2, "ct": 5, "cndata": 8, "cnc
 
 def open_read_file(file_path, file_extension=""):
     the_file = open(file_path + file_extension, 'rb')
-    #return mmap(the_file.fileno(), 0, prot=PROT_READ)
-    return mmap(the_file.fileno(), 0, access=ACCESS_READ)
+    return mmap(the_file.fileno(), 0, prot=PROT_READ)
 
 def read_str_from_file(file_path, file_extension=""):
     with open(file_path + file_extension, 'rb') as the_file:
